# Jetty: Full-Stack Data Access Control

## Installation

Install Jetty by running `pip install jetty-core`

## First Use

Once Jetty is installed, create a Jetty project by running `jetty init`.
The application will walk you through the steps you need to connect Jetty to your data infrastructure. Once Jetty is configured, you can fetch up to date data access information and launch the Explore UI with `jetty explore --fetch`.

## Updating Access Information

Use `jetty fetch` to get an updated view of your data stack.

## Launching the UI

Launch the Explore UI for the most recent fetch of your data with `jetty explore`.

## Reaching Out

We would love to know what you think! Feel free to reach out to us at [support@get-jetty.com](support@get-jetty.com)
